@@ -23,7 +23,7 @@ LessonModel::LessonModel(QObject *parent)
 KEduVocContainer *LessonModel::rootContainer() const
 {
     if (!m_doc) {
-        return 0;
+        return nullptr;
     }
     return m_doc->lesson();
 }
@@ -100,3 +100,5 @@ void LessonModel::splitLesson(const QModelIndex &containerIndex, int entriesPerL
         }
     }
 }
+
+#include "moc_lessonmodel.cpp"
