@@ -6,6 +6,7 @@
 #include "audiobutton.h"
 
 #include <KLocalizedString>
+#include <QAudioOutput>
 
 using namespace Practice;
 
@@ -31,25 +32,26 @@ void AudioButton::playAudio()
 {
     if (!m_player) {
         m_player = new QMediaPlayer(this);
-        connect(m_player, &QMediaPlayer::stateChanged, this, &AudioButton::playerStateChanged);
+        connect(m_player, &QMediaPlayer::playbackStateChanged, this, &AudioButton::playerStateChanged);
+        m_player->setAudioOutput(new QAudioOutput);
     } else {
-        if (m_player->state() == QMediaPlayer::PlayingState) {
+        if (m_player->playbackState() == QMediaPlayer::PlayingState) {
             m_player->stop();
         }
     }
-    m_player->setMedia(m_url);
-    m_player->setVolume(50);
+    m_player->setSource(m_url);
+    m_player->audioOutput()->setVolume(50);
     m_player->play();
 }
 
 void AudioButton::stopAudio()
 {
-    if (m_player && m_player->state() == QMediaPlayer::PlayingState) {
+    if (m_player && m_player->playbackState() == QMediaPlayer::PlayingState) {
         m_player->stop();
     }
 }
 
-void AudioButton::playerStateChanged(QMediaPlayer::State newState)
+void AudioButton::playerStateChanged(QMediaPlayer::PlaybackState newState)
 {
     switch (newState) {
     case QMediaPlayer::PlayingState:
